Improve this Doc

# $compile

Here are the list of errors in the $compile namespace.

Name | Description
--- | ---
baddir | Invalid Directive/Component Name
badrestrict | Invalid Directive Restrict
ctreq | Missing Required Controller
infchng | Unstable `$onChanges` hooks
iscp | Invalid Isolate Scope Definition
missingattr | Missing required attribute
multidir | Multiple Directive Resource Contention
multilink | Linking Element Multiple Times
noctrl | Controller is required.
nodomevents | Interpolated Event Attributes
nonassign | Non-Assignable Expression
noslot | No matching slot in parent directive
reqslot | Required transclusion slot
selmulti | Binding to Multiple Attribute
tpload | Error Loading Template
tplrt | Invalid Template Root
uterdir | Unterminated Directive